aboutsummaryrefslogtreecommitdiffstats
path: root/erts/emulator/beam/erl_time_sup.c
diff options
context:
space:
mode:
authorBjörn-Egil Dahlberg <[email protected]>2010-12-14 13:44:41 +0100
committerBjörn-Egil Dahlberg <[email protected]>2010-12-20 17:04:35 +0100
commitcc38c833de443fa550ecf17201b6aac0d0ad25f9 (patch)
tree5f50a607cd37235de6b4a27357cd949d7f2b8769 /erts/emulator/beam/erl_time_sup.c
parentce6172a1badb21a97a4235db27e2f991f01d5b0a (diff)
downloadotp-cc38c833de443fa550ecf17201b6aac0d0ad25f9.tar.gz
otp-cc38c833de443fa550ecf17201b6aac0d0ad25f9.tar.bz2
otp-cc38c833de443fa550ecf17201b6aac0d0ad25f9.zip
Refactor timer interface
Diffstat (limited to 'erts/emulator/beam/erl_time_sup.c')
-rw-r--r--erts/emulator/beam/erl_time_sup.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/erts/emulator/beam/erl_time_sup.c b/erts/emulator/beam/erl_time_sup.c
index 7b8706ea13..932bf678cd 100644
--- a/erts/emulator/beam/erl_time_sup.c
+++ b/erts/emulator/beam/erl_time_sup.c
@@ -389,7 +389,7 @@ static void do_erts_deliver_time(const SysTimeval *current)
this by simply pretend as if the time stood still. :) */
if (elapsed > 0) {
- do_time_add(elapsed);
+ erts_do_time_add(elapsed);
last_delivered = cur_time;
}
}
@@ -811,9 +811,9 @@ void erts_time_remaining(SysTimeval *rem_time)
#endif
long elapsed;
- /* next_time() returns no of ticks to next timeout or -1 if none */
+ /* erts_next_time() returns no of ticks to next timeout or -1 if none */
- if ((ticks = next_time()) == -1) {
+ if ((ticks = erts_next_time()) == -1) {
/* timer queue empty */
/* this will cause at most 100000000 ticks */
rem_time->tv_sec = 100000;